@@ -47,6 +47,8 @@
 #'   occur for lowly expressed genes because the ratio of two small numbers can be impractically large. For example, limiting
 #'   the range of log fold changes can clarify the patterns in a volcano plot. Default: `10` which
 #'   corresponds to a thousand-fold (2^10) increase in expression.
+#' @param compute_lfc_se Compute standard errors for the log fold changes, and add a column `lfc_se` to the
+#'   returned dataframe. Only has an effect when using `contrast` instead of `reduced_design`. Default: `FALSE`
 #'
 #' @details
 #' The `cond()` helper function simplifies the specification of a contrast for complex experimental designs.
@@ -65,11 +67,12 @@
 #'   \item{name}{the rownames of the input data}
 #'   \item{pval}{the p-values of the quasi-likelihood ratio test}
 #'   \item{adj_pval}{the adjusted p-values returned from [p.adjust()]}
-#'   \item{f_statistic}{the F-statistic: \eqn{F = (Dev_full - Dev_red) / (df_1 * disp_ql-shrunken)}}
+#'   \item{f_statistic}{the F-statistic: \eqn{F = (Dev_{full} - Dev_{red}) / (df_1 * disp_{ql-shrunken})}}
 #'   \item{df1}{the degrees of freedom of the test: `ncol(design) - ncol(reduced_design)`}
 #'   \item{df2}{the degrees of freedom of the fit: `ncol(data) - ncol(design) + df_0`}
 #'   \item{lfc}{the log2-fold change. If the alternative model is specified by `reduced_design` will
 #'    be `NA`.}
+#'   \item{lfc_se}{the standard error of the log2-fold change. Only calculated if `compute_lfc_se == TRUE`.}
 #' }
 #'
 #' @examples
@@ -137,6 +140,7 @@ test_de <- function(fit,
                     pval_adjust_method = "BH", sort_by = NULL,
                     decreasing = FALSE, n_max = Inf,
                     max_lfc = 10,
+                    compute_lfc_se = FALSE,
                     verbose = FALSE){
   # Capture all NSE variables
   subset_to_capture <- substitute(subset_to)
@@ -146,6 +150,7 @@ test_de <- function(fit,
             subset_to = subset_to_capture, pseudobulk_by = pseudobulk_by_capture,
             pval_adjust_method = pval_adjust_method, sort_by = sort_by_capture,
             decreasing = decreasing, n_max = n_max, max_lfc = max_lfc,
+            compute_lfc_se = compute_lfc_se,
             verbose = verbose,
             env = parent.frame())
 }
@@ -160,10 +165,12 @@ test_de_q <- function(fit,
                       subset_to = NULL, pseudobulk_by = NULL,
                       pval_adjust_method = "BH", sort_by = NULL,
                       decreasing = FALSE, n_max = Inf, max_lfc = 10,
+                      compute_lfc_se = FALSE,
                       verbose = FALSE,
                       env = parent.frame()){
 
   ridge_penalty <- fit$ridge_penalty
+
   if(! is.matrix(full_design) || length(full_design) != length(fit$model_matrix) || ! all(full_design == fit$model_matrix) ){
     full_design <- handle_design_parameter(full_design, fit$data, SummarizedExperiment::colData(fit$data), NULL)$model_matrix
     ridge_penalty <- NULL
@@ -243,6 +250,15 @@ test_de_q <- function(fit,
       diag(ridge_penalty, nrow = length(ridge_penalty)) %*% rot
     }
     lfc <- fit$Beta %*% cntrst / log(2)
+
+    if (compute_lfc_se) {
+      pred <- predict(fit, se.fit=TRUE, type='link',
+                      offset=0, #for asserting equality with lfc
+                      newdata=matrix(cntrst, nrow=1))
+
+      lfc_se <- pred$se.fit[,1] / log(2)
+    }
+
     lfc[lfc < -max_lfc] <- -max_lfc
     lfc[lfc > max_lfc] <- max_lfc
   }else{
@@ -271,6 +287,9 @@ test_de_q <- function(fit,
       diag(ridge_penalty, nrow = length(ridge_penalty)) %*% rot
     }
     lfc <- NA
+    if (compute_lfc_se) {
+     lfc_se <- NA
+    }
   }
   if(verbose){message("Fit reduced model")}
   data <- fit$data
@@ -313,6 +332,9 @@ test_de_q <- function(fit,
                     f_statistic = f_stat, df1 = df_test, df2 = df_fit,
                     lfc = lfc,
                     stringsAsFactors = FALSE, row.names = NULL)
+  if (compute_lfc_se) {
+    res$lfc_se <- lfc_se
+  }
   sort_by_e <- eval_with_q(sort_by, res, env = env)
   res <- if(is.null(sort_by_e)) {
     res
