@@ -9,8 +9,6 @@ set.seed(2)
 knitr::include_graphics("img/kang_data_overview.png")
 
 ## -----------------------------------------------------------------------------
-library(SummarizedExperiment)
-library(SingleCellExperiment)
 sce <- muscData::Kang18_8vs8() 
 # Keep only genes with more than 5 counts
 sce <- sce[rowSums(counts(sce)) > 5,]
