@@ -10,6 +10,11 @@ double compute_gp_deviance_mask(double y, double mu, double theta) {
   return compute_gp_deviance(y, mu, theta);
 }
 
+// [[Rcpp::export(name = "compute_gp_deviance_sum")]]
+double compute_gp_deviance_sum_mask(NumericVector y, NumericVector mu, double theta) {
+  return compute_gp_deviance_sum(y, mu, theta);
+}
+
 
 // [[Rcpp::export(name = "compute_gp_deviance_residuals_matrix")]]
 arma::Mat<double> compute_gp_deviance_residuals_matrix_mask(const SEXP Y_SEXP, const arma::Mat<double>& Mu, NumericVector thetas) {
